%%
%% This is file `title-Spacer.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% uni-titlepage.dtx  (with options: `driver,Spacer')
%% Copyright (c) 2009-2022 by Markus Kohm <komascript(at)gmx.info>
%% 
%% This file was generated from file(s) of uni-titlepage distribution.
%% 
%% ----------------------------------------------------------------------
%% 
%% This work may be distributed and/or modified under the conditions of
%% the LaTeX Project Public License, version 1.3c of the license.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainer and author of this work is Markus Kohm.
%% 
%% This file may only be distributed together with
%% the file `uni-titlepage.dtx'.
%% You may however distribute the file `uni-titlepage.dtx' without this file.
%% 
\ProvidesFile{%
  title%
  -Spacer%
 .def%
}[%
2025-08-12 v1.4
KOMA presents the title page project
]
\begingroup
  \def\PackageNotLoadedError#1{%
    \GenericError{%
      (#1)\@spaces\@spaces\@spaces\@spaces
    }{%
      File `#1' Error: package `uni-titlepage' hasn't been loaded%
    }{%
      This definition file was made to be loaded by package
      `uni-titlepage'.\MessageBreak
      You may not use it without package `uni-titlepage'!\MessageBreak
      See the documentation of package `uni-titlepage' for explanation.%
    }%
  }%
  \ifx\csname uni-titlepage.sty@vers\endcsname\relax
    \PackageNotLoadedError{%
      title-Spacer.def%
    }%
  \fi
\endgroup
\DefineFamilyMember[%
  Spacer%
]{title}
\providecommand*{\title@rulewidth}{%
  0pt%
}
\providecommand*{\title@rulesep}{%
  \ifdim \title@rulewidth>\z@ 10pt\else \z@\fi
}
\providecommand*{\title@rulecolor}{}
\DefineFamilyKey[%
  Spacer%
]{title}{rulewidth}{%
  \gdef\title@rulewidth{\dimexpr #1\relax}%
  \FamilyKeyStateProcessed
}
\DefineFamilyKey[%
  Spacer%
]{title}{rulesep}{%
  \gdef\title@rulesep{\dimexpr #1\relax}%
  \FamilyKeyStateProcessed
}
\FamilyStringKey[%
  Spacer%
]{title}{rulecolor}{\title@rulecolor}
\renewcommand*{\inittitle}{%
}
\renewcommand*{\makemaintitle}{%
  \begin{%
    titlepage}
    \setlength{\parskip}{\z@}%
    \setlength{\parindent}{\z@}%
    \setlength{\parfillskip}{\z@\@plus 1fil}%
    \linespread{1}\selectfont
    \@titlepagefont
    \raggedright
    \raisebox{0pt}[\ht\strutbox][\dimexpr\textheight-\ht\strutbox\relax]{%
      \ifx\title@rulecolor\@empty\else
        \@ifundefined{color}{}{\color{\title@rulecolor}}%
      \fi
      \rule[\dimexpr-.667\headsep-\textheight\relax]
           {\title@rulewidth}
           {\dimexpr\textheight+2\headsep\relax}\kern\title@rulesep
    }%
    \parbox[t][\textheight][t]
           {\dimexpr \textwidth-\title@rulewidth-\title@rulesep\relax}{%
      \raggedright
      \ifx\@titlehead\@empty\else
        \raisebox{\dimexpr\ht\strutbox-\totalheight\relax}{%
          \parbox[t]{\linewidth}{\@titlehead}%
        }\par
        \vskip 2\baselineskip
      \fi
      {\leavevmode\subject@font{%
          \large\strut\ignorespaces\@subject\par\vskip 2\baselineskip}}%
      {\def\and{\\}\csname @authorfont\endcsname{\large\@author}\par
        \vskip .5\baselineskip}%
      {\titlefont{\LARGE\strut\ignorespaces\@title\par}}%
      {\@subtitlefont{%
          \large\vskip.5\baselineskip\strut\ignorespaces\@subtitle\par}}%
      \vfill
      {\csname @publisherfont\endcsname{\large\@publisher\par}}%
      {\csname @datefont\endcsname{\large\strut\ignorespaces\@date\par}}%
    }%
  \end{%
    titlepage}
}
\providecommand*{\@uppertitleback}{}
\providecommand{\uppertitleback}[1]{\gdef\@uppertitleback{#1}}
\DefineFamilyKey[%
  Spacer%
]{title}{uppertitleback}{\uppertitleback{#1}\FamilyKeyStateProcessed}
\providecommand*{\@lowertitleback}{}
\providecommand{\lowertitleback}[1]{\gdef\@lowertitleback{#1}}
\DefineFamilyKey[%
  Spacer%
]{title}{lowertitleback}{\lowertitleback{#1}\FamilyKeyStateProcessed}
\renewcommand*{\makemaintitleback}{%
  \begin{titlepage}
    \setlength{\parskip}{\z@}%
    \setlength{\parindent}{\z@}%
    \setlength{\parfillskip}{\z@\@plus 1fil}%
    \begin{minipage}[t]{\textwidth}
      \@titlepagefont{\@uppertitleback}%
    \end{minipage}\par
    \vfill
    \begin{minipage}[b]{\textwidth}
      \@titlepagefont{\@lowertitleback}%
    \end{minipage}
  \end{titlepage}
}
\providecommand*{\@extratitle}{}
\providecommand{\extratitle}[1]{\gdef\@extratitle{#1}}
\DefineFamilyKey[%
  Spacer%
]{title}{extratitle}{\extratitle{#1}\FamilyKeyStateProcessed}
\renewcommand*{\makepretitle}{%
  \ifx\@extratitle\@empty\else
    \begin{titlepage}
      \noindent\@extratitle
    \end{titlepage}
  \fi
}%
\renewcommand*{\makepretitleback}{%
  \ifx\@extratitle\@empty\else\begin{titlepage}\null\end{titlepage}\fi
}
\renewcommand*{\makeposttitle}{%
  \ifx\@dedication\@empty\else
    \begin{titlepage}
      \null\vfill
      {\centering\csname @dedicationfont\endcsname{\@dedication \par}}%
      \vskip \z@ \@plus 3fill
    \end{titlepage}
  \fi
}
\renewcommand*{\makeposttitleback}{%
  \ifx\@dedication\@empty\else\begin{titlepage}\null\end{titlepage}\fi
}
\endinput
%%
%% End of file `title-Spacer.def'.
